@@ -63,6 +63,12 @@ def merge_runs(input_dir1, input_dir2, map_df, output, arguments):
                     total_depth = n_depth_1 + n_depth_2
                     merged_header += f"#Number of reads outside of the tile:{total_depth}\n"
                     continue
+                if "Raw read depth:" in line1:
+                    n_depth_1 = int(line1.split(":")[1])
+                    n_depth_2 = int(line2.split(":")[1])
+                    total_depth = n_depth_1 + n_depth_2
+                    merged_header += f"#Raw read depth:{total_depth}\n"
+                    continue
                 merged_header += line1.strip() + "; " + line2
         output_f = open(os.path.join(output, f"counts_sample_{row['Sample ID_run1']}-{row['Sample ID_run2']}.csv"), "w")
         output_f.write(merged_header)
